DestiNet - Knowledge Networking Portal for Sustainable & Responsible Tourism

DestiNet
Knowledge Networking Portal for Sustainable & Responsible Tourism

- About
  - History
  - Create your free account
  - Guidance for DestiNet Users
  - Uses of DestiNet
- Who is Who
  - Governments & Administrations
  - Individuals
  - NGOs, Partnerships, Networks, Projects
  - Education, Research, Consultancy
  - Destinations
  - Businesses
  - MARKET PLACE
  - MARKET SOLUTIONS
  - ATLAS
  - DestiNet Users
  - ECOTRANS
- Topics
  - Natural and Cultural Heritage
  - Climate Change - Energy and Resource Efficiency
  - Destination Management and Good Governance
  - Transport and Mobility
  - Sustainable Supply Chain Management
  - Knowledge Networking, Training and Education
  - Quality Assessment, Certification and Marketing
  - Sustainable Consumption and Production & Tourism
- Resources
  - documents and publications
  - useful link for documents and information
  - Competence Training for Sustainable & Responsible Tourism Certification
  - for Businesses
  - for Destinations
  - for NGOs, Partnerships, Networks
  - for Governments & Administrations
  - for Education, Research, Consultancy
  - for Travellers
  - DEVELOPMENT SECTION
- Good Practice
  - Good Practice Examples: Destinations (Selection)
- Market Place
  - CERTIFICATES & AWARDS
  - CERTIFIED TOURISM (certifiers section)
  - Transport & Mobility Services
  - Accommodation Providers
  - Green Destinations
  - Restaurants & Catering Services
  - Tour operators, Travel agents, Intermediaries
  - Attractions
  - Activities
  - Travel Packages
- Observatory
  - Local Level Observatory Processes
  - Regional Level Observatory Processes
  - National level Observatory Processes
  - European Level Observatory Processes
  - Global Observatory Processes
  - Topic Centre for Observing Sustainable Tourism
- ATLAS
- Google Site Search

EW » Home
My DestiNet
Partnerships
ECOTRANS – DESTINET SERVICES
© Copyright ECOTRANS
2009 - 2014 All Rights Reserved. All logos and trademarks in this site are property of their respective owners.
Contact us · Disclaimer
My role and interest in sustainable and responsible tourism is ..

# DestiNet account application

Registration here will link you into a global responsible and sustainable tourism knowledge network, and give you access to the networks' knowledge bases, market places and monttoring systems. For now we need a minimum amount of information to list you on a global map of tourism stakeholders - later you can complete your full profile to save time now.

Basic info
Create a username for this site *
First name *
Last name *
Email address *
Password *
Password verification: *
Organization Category *

What type of organization are you?

### Full address

Postal address
Country *

Tip: you can type free text in the field below or pick words from the list

[Expand all] [Collapse all] [View glossary]

This is the minimum information we require. You can submit the form now and fill the rest in later if you want to make the best use of the DestiNet Portal.

Further information

Further Information that will give you more access to the global knowledge base and market place - fill this in to let other tourism stakeholders know who you are, what topics interest you, what is your area of activity or expertise and/or what products/services you offer.

Name of your organisation
Geographical location

Please provide the best fit for a geographical location. You can place the information using the options below.

A. Identifying a location on the map:

- Move inside the map and zoom in to the most relevant location;
- Click again at that specific location, a pin will appear and the coordinates for that point will be automatically retrieved and filled in.

B. If you know the address:

- Type the address in the Address field;
- Click on the Center map button, right next to the Address field, and get the coordinates for the address.

[Hide map ▼]

Latitude
Longitude

Use the address to retrieve the location coordinates (e.g. Kongens Nytorv 6, 1050 Copenhagen K, Denmark)

Address

### LOCAL TO GLOBAL QUALITY-ASSESSED MARKET PLACE LISTINGS.

#### List yourself in DestINet's Quality Assessed Sustainable Tourism Global Market Place

(NB. Listing here will be charged according to the DestiNet Market Access Services current price list.)

List yourself in DestINet's Sustainable Tourism Global Market Place

Do you wish to register a sustainable tourism business activity or service in the global green market place?

No Yes

#### Solutions Supporting Sustainable Tourism

(NB. Listing here will be charged according to the DestiNet Market Access Services current price list.)

Supporting Solutions

Do you offer services to support sustainable tourism development?

No Yes

### ABOUT YOU OR YOUR ORGANISATION

Operational level - At what territorial level is your organisation operating?

Operational level *

Click on the items from the list below to select/deselect them.

Landscape Type - Do you have a focus on a specific landscape type?
Landscape type

Click on one or more items from the list below to select/deselect them.

Topics - Please select the topics of main interest /fields of activity/ competence) to you.
Topics

Click on one or more items from the list below to select/deselect them.

Membership
Memberships

Click here to be registered as member/user of:

About Me *

Please provide a short profile that will give others the opportunity to know your work and interests.